#!/usr/bin/env bash

OUTFILE=squares.txt
CHKPOINTFILE=checkpoint.txt
evict=0

# Checkpointing function, to be invoked on SIGTERM
checkpoint() {
  evict=1
  kill $sleeppid
}

trap checkpoint SIGTERM

# Some debugging information
echo "Running on $(/bin/hostname)"
echo "Current directory = $(pwd)"

# Is there a previous checkpoint?
if [ -f $CHKPOINTFILE ]; then
  i=$(<$CHKPOINTFILE)
  echo "Checkpoint found, starting at $((i+1))"
  rm $CHKPOINTFILE
else
  i=0
fi

ENDLOOP=${1:-180}
echo "Loop from $((i+1)) to $ENDLOOP"
while ((++i <= ENDLOOP)); do
  # Simulate some CPU load
  yes > /dev/null &
  loadpid=$!
  sleep 1 &
  sleeppid=$!
  wait $sleeppid

  # Terminate the fake load
  kill $loadpid

  # Write the 'result'
  echo "${i}^2 = $((i*i))" >> $OUTFILE

  # Exit if SIGTERM received
  if [[ $evict -eq 1 ]]; then break; fi
done

if [[ $evict -ne 1 ]]; then
  echo "........ Done"
else
  echo "Got SIGTERM at i = $i, writing checkpoint file"
  echo "$i" > $CHKPOINTFILE
  echo "See you in the next execution slot!"
fi

